fisx: Member List

fisx

fisx::Layer Member List

This is the complete list of members for fisx::Layer, including all inherited members.

getComposition(const Elements &elements) const | fisx::Layer |
getComposition(const Elements &elements) (defined in fisx::Layer) | fisx::Layer |
getDensity() const (defined in fisx::Layer) | fisx::Layer | inline
getFunnyFactor() const (defined in fisx::Layer) | fisx::Layer | inline
getMassAttenuationCoefficients(const double &energy, const Elements &elements) const | fisx::Layer |
getMassAttenuationCoefficients(const std::vector< double > &energies, const Elements &elements) const | fisx::Layer |
getMaterial() const | fisx::Layer | inline
getMaterialName() const (defined in fisx::Layer) | fisx::Layer | inline
getPeakFamilies(const double &energy, const Elements &elements) const | fisx::Layer |
getThickness() const (defined in fisx::Layer) | fisx::Layer | inline
getTransmission(const double &energy, const Elements &elements, const double &angle=90.0) const | fisx::Layer |
getTransmission(const std::vector< double > &energy, const Elements &elements, const double &angle=90.0) const | fisx::Layer |
hasMaterialComposition() const | fisx::Layer |
Layer(const std::string &name="", const double &density=0.0, const double &thickness=0.0, const double &funnyFactor=1.0) (defined in fisx::Layer) | fisx::Layer |
name (defined in fisx::Layer) | fisx::Layer |
operator<< (defined in fisx::Layer) | fisx::Layer | friend
setDensity(const double &density) (defined in fisx::Layer) | fisx::Layer |
setMaterial(const std::string &materialName) (defined in fisx::Layer) | fisx::Layer |
setMaterial(const Material &material) (defined in fisx::Layer) | fisx::Layer |
setThickness(const double &thickness) (defined in fisx::Layer) | fisx::Layer |